# Argument

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**auto** | **str** |  | [optional] 
**default** | **bool** |  | [optional] 
**default_value** | **str** |  | [optional] 
**deprecated** | **bool** |  | [optional] 
**description** | **str** |  | [optional] 
**is_array** | **bool** |  | [optional] 
**name** | **str** |  | [optional] 
**predefined** | **list[str]** |  | [optional] 
**required** | **bool** |  | [optional] 
**secret** | **bool** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


